@@ -166,7 +166,7 @@ from ae.base import (   # type: ignore # noqa: F401 # pylint:disable=unused-impo
     in_wd, norm_path, project_main_file, read_file)
 
 
-__version__ = '0.2.0'
+__version__ = '0.2.2'
 
 
 APP_PRJ = 'app'                                             #: gui application project
@@ -205,7 +205,7 @@ STK_CLASSIFIERS = [
             "Programming Language :: Python",
             "Programming Language :: Python :: 3",
             "Programming Language :: Python :: 3.6",
-            "Topic :: Software Development :: Libraries :: Development Tools",
+            "Topic :: Software Development :: Libraries :: Python Modules",
         ]                                                   #: project classifiers defaults
 STK_KEYWORDS = [
             'configuration',
@@ -560,8 +560,7 @@ def project_env_vars(project_path: str = "", cae: Optional[Any] = None, from_set
             if isinstance(pev, dict):                                                       # PevType type
                 if cae:
                     _init_app_configs(pev, cae)             # overwrite constants with cae app config vars
-                    # interim/temporary commenting out TODO
-                    # _sync_stk_to_setup_kwargs(pev)        # sync STK_* constants patched by app config to setup_kwargs
+                    _sync_stk_to_setup_kwargs(pev)        # sync STK_* constants patched by app config to setup_kwargs
                 return pev
 
     pev = _init_pev(cae, package_name, project_path)
